Package: rentrez
Version: 1.2.4
Date: 2025-06-11
Title: 'Entrez' in R
Authors@R: c(
 person("David", "Winter", role=c("aut", "cre"), 
        email = "david.winter@gmail.com", 
        comment = c(ORCID = "0000-0002-6165-0029")),
 person("Scott", "Chamberlain", role="ctb", email = "myrmecocystus@gmail.com",
        comment = c(ORCID = "0000-0003-1444-9135")),
 person("Han","Guangchun", role=c("ctb"),email="hanguangchun@gmail.com",
        comment = c(ORCID = "0000-0001-9277-2507"))
 )
Depends: R (>= 2.6.0)
Imports: XML, httr (>= 0.5), jsonlite (>= 0.9)
Suggests: testthat, knitr, rmarkdown
URL: https://github.com/ropensci/rentrez/
BugReports: https://github.com/ropensci/rentrez/issues/
Description: Provides an R interface to the NCBI's 'EUtils' API, 
    allowing users to search databases like 'GenBank' 
    <https://www.ncbi.nlm.nih.gov/genbank/> and 'PubMed' 
    <https://pubmed.ncbi.nlm.nih.gov/>, process the 
    results of those searches and pull data into their R sessions.
VignetteBuilder: knitr
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-06-11 10:15:33 UTC; dawinter
Author: David Winter [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6165-0029>),
  Scott Chamberlain [ctb] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>),
  Han Guangchun [ctb] (ORCID: <https://orcid.org/0000-0001-9277-2507>)
Maintainer: David Winter <david.winter@gmail.com>
Repository: CRAN
Date/Publication: 2025-06-11 11:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 06:02:14 UTC; unix
