# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,eInfoList)
S3method(extract_from_esummary,esummary)
S3method(extract_from_esummary,esummary_list)
S3method(parse_esearch,XMLInternalDocument)
S3method(parse_esearch,list)
S3method(parse_esummary,XMLInternalDocument)
S3method(parse_esummary,list)
S3method(print,eInfoEntry)
S3method(print,eInfoLink)
S3method(print,eInfoSearch)
S3method(print,elink)
S3method(print,elink_classic)
S3method(print,elink_list)
S3method(print,esearch)
S3method(print,esummary)
S3method(print,esummary_list)
S3method(print,linkout)
S3method(print,multi_pubmed_record)
S3method(print,pubmed_record)
S3method(print,web_history)
export(entrez_citmatch)
export(entrez_db_links)
export(entrez_db_searchable)
export(entrez_db_summary)
export(entrez_dbs)
export(entrez_fetch)
export(entrez_global_query)
export(entrez_info)
export(entrez_link)
export(entrez_post)
export(entrez_search)
export(entrez_summary)
export(extract_from_esummary)
export(linkout_urls)
export(parse_pubmed_xml)
export(set_entrez_key)
importFrom(XML,xmlChildren)
importFrom(XML,xmlGetAttr)
importFrom(XML,xmlName)
importFrom(XML,xmlSApply)
importFrom(XML,xmlToList)
importFrom(XML,xmlTreeParse)
importFrom(XML,xmlValue)
importFrom(XML,xpathApply)
importFrom(XML,xpathSApply)
importFrom(jsonlite,fromJSON)
